@@ -65,28 +65,18 @@ class ArticleAdmin(BaseAdminClass):
     date_hierarchy = 'publication_date'
     fieldsets = (
         #(_('Navigation'), {'fields': ('navigation_parent',)}),
-        (_('General'), {'fields': ('slug', 'title', 'content')}),
-        (_('Advanced'), {'fields': ('sites', 'template', 'category', 'logo', 'in_newsletter')}),
-        (_('Publication'), {'fields': ('publication', 'publication_date', 'headline', 'is_homepage', 'homepage_for_site', 'created', 'modified')}),
-        (_('Summary'), {'fields': ('summary',)}),
-        (_('Debug'), {'fields': ('temp_logo',)}),
+        (_(u'General'), {'fields': ('slug', 'title', 'subtitle', 'publication', )}),
+        (_(u'Settings'), {'fields': ('sites', 'template', 'category', 'headline', 'is_homepage', 'logo', 'in_newsletter')}),
+        (_(u'Advanced'), {'fields': ('publication_date', 'homepage_for_site', 'created', 'modified')}),
+        (_(u'Content'), {'fields': ('content','summary',)}),
+        (_(u'Debug'), {'fields': ('temp_logo',)}),
     )
     
-    def __init__(self, *args, **kwargs):
-        if not can_rewrite_url():
-            slug_fields = [] 
-            if is_localized():
-                for (lang, _name) in settings.LANGUAGES:
-                    slug_fields.append('slug_'+lang)
-            else:
-                slug_fields = ['slug']
-            self.readonly_fields = slug_fields + self.readonly_fields
-        super(ArticleAdmin, self).__init__(*args, **kwargs)
-
     def get_form(self, request, obj=None, **kwargs):
         form = super(ArticleAdmin, self).get_form(request, obj, **kwargs)
         form.current_user = request.user
         return form
+    
 admin.site.register(get_article_class(), ArticleAdmin)
 
 admin.site.register(models.Link)
