@@ -1,5 +1,5 @@
 from django import forms
-from coop_cms.models import NavType, NavNode, Newsletter, NewsletterSending, Link, Document, Fragment
+from coop_cms.models import NavType, NavNode, Newsletter, NewsletterSending, Link, Document, Fragment, BaseArticle
 from django.contrib.contenttypes.models import ContentType
 from settings import get_navigable_content_types
 from django.core.exceptions import ValidationError
@@ -14,7 +14,9 @@ from django.core.urlresolvers import reverse
 from coop_cms.utils import dehtml
 from datetime import datetime
 from django.utils.timezone import now as dt_now
-from coop_cms.widgets import ChosenSelectMultiple
+from coop_cms.widgets import ChosenSelectMultiple, ReadOnlyInput
+from settings import is_localized, can_rewrite_url
+from django.contrib.auth.models import Permission
 
 class NavTypeForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
@@ -62,16 +64,16 @@ class ArticleForm(AlohaEditableModelForm):
         fields = ('title', 'subtitle', 'content', 'logo')
         no_aloha_widgets = ('logo',)
 
-    def set_logo_size(self, logo_size=None):
-        thumbnail_src = self.logo_thumbnail(logo_size)
+    def set_logo_size(self, logo_size=None, logo_crop=None):
+        thumbnail_src = self.logo_thumbnail(logo_size, logo_crop)
         update_url = reverse('coop_cms_update_logo', args=[self.article.id])
         self.fields['logo'].widget = ImageEdit(update_url,
             thumbnail_src.url if thumbnail_src else '',
-            attrs={"class": "resiazable"})
+            attrs={"class": "resizable"})
 
-    def logo_thumbnail(self, logo_size=None):
+    def logo_thumbnail(self, logo_size=None, logo_crop=None):
         if self.article:
-            return self.article.logo_thumbnail(True, logo_size=logo_size)
+            return self.article.logo_thumbnail(True, logo_size=logo_size, logo_crop=logo_crop)
 
     def clean_title(self):
         if getattr(settings, 'COOP_CMS_TITLE_OPTIONAL', False):
@@ -158,6 +160,24 @@ class ArticleAdminForm(forms.ModelForm):
         templates = get_article_templates(self.article, self.current_user)
         if templates:
             self.fields['template'].widget = forms.Select(choices=templates)
+        
+        Article = get_article_class()
+        
+        self.slug_fields = []
+        if is_localized():
+            for (lang, _name) in settings.LANGUAGES:
+                self.slug_fields.append('slug_'+lang)
+        else:
+            self.slug_fields = ['slug']
+        
+        can_change_article_slug = can_rewrite_url()
+        
+        if not can_change_article_slug:
+            can_change_article_slug = (self.article.publication != BaseArticle.PUBLISHED) if self.article else True
+        
+        for slug_field in self.slug_fields:
+            if not can_change_article_slug:
+                self.fields[slug_field].widget = ReadOnlyInput()
 
     class Meta:
         model = get_article_class()
@@ -212,6 +232,8 @@ class ArticleSettingsForm(WithNavigationModelForm):
         kwargs['initial'] = initials
         super(ArticleSettingsForm, self).__init__(*args, **kwargs)
 
+        self.fields['category'].queryset = self.fields['category'].queryset.filter(sites=settings.SITE_ID)
+
         choices = get_article_templates(article, user)
         if choices:
             self.fields["template"] = forms.ChoiceField(choices=choices)
