@@ -16,7 +16,7 @@ from django.utils.html import escape
 from django.core.exceptions import ValidationError
 # from html_field.db.models import HTMLField
 # from html_field import html_cleaner
-from coop_cms.settings import get_article_class, get_article_logo_size, get_newsletter_item_classes
+from coop_cms.settings import get_article_class, get_article_logo_size, get_newsletter_item_classes, get_article_logo_crop
 from coop_cms.settings import get_navtree_class, is_localized, COOP_CMS_NAVTREE_CLASS, get_article_templates
 from coop_cms.settings import get_default_logo, is_requestprovider_installed
 from coop_cms.utils import dehtml
@@ -115,8 +115,11 @@ class NavNode(models.Model):
     in_navigation = models.BooleanField(_("in navigation"), default=True)
 
     def get_absolute_url(self):
-        if self.content_object:
-            return self.content_object.get_absolute_url()
+        try:
+            if self.content_object:
+                return self.content_object.get_absolute_url()
+        except AttributeError:
+            pass
         return None
     
     def is_active_node(self):
@@ -287,6 +290,7 @@ class ArticleCategory(models.Model):
     ordering = models.IntegerField(_(u'ordering'), default=0)
     in_rss = models.BooleanField(_(u'in rss'), default=False,
         help_text=_(u"The articles of this category will be listed in the main rss feed"))
+    sites = models.ManyToManyField(Site, verbose_name=_(u'site'), default=[settings.SITE_ID])
 
     def __unicode__(self):
         return self.name
@@ -304,7 +308,15 @@ class ArticleCategory(models.Model):
     class Meta:
         verbose_name = _(u'article category')
         verbose_name_plural = _(u'article categories')
-
+        
+    def save(self, *args, **kwargs):
+        is_new = not bool(self.id)
+        ret = super(ArticleCategory, self).save(*args, **kwargs)
+        
+        if is_new:
+            site = Site.objects.get(id=settings.SITE_ID)
+            self.sites.add(site)
+            ret = super(ArticleCategory, self).save()
 
 class BaseNavigable(TimeStampedModel):
 
@@ -363,7 +375,9 @@ class BaseArticle(BaseNavigable):
             img_root = settings.CMS_ARTICLE_LOGO_FOLDER
         except AttributeError:
             img_root = 'cms_logos'
-        return u'{0}/{1}/{2}'.format(img_root, self.id, filename)
+        basename = os.path.basename(filename)   
+        return u'{0}/{1}/{2}'.format(img_root, self.id, basename)
+        
 
     #slug = AutoSlugField(populate_from='title', max_length=100, unique=True)
     slug = models.CharField(max_length=100, unique=True, db_index=True, blank=False)
@@ -396,7 +410,8 @@ class BaseArticle(BaseNavigable):
     def next_in_category(self):
         if self.category:
             try:
-                return get_article_class().objects.filter(category=self.category, publication=BaseArticle.PUBLISHED,
+                return get_article_class().objects.filter(sites__id=settings.SITE_ID, category=self.category,
+                    publication=BaseArticle.PUBLISHED,
                     publication_date__gt=self.publication_date).order_by('publication_date')[0]
             except IndexError:
                 pass
@@ -404,12 +419,14 @@ class BaseArticle(BaseNavigable):
     def previous_in_category(self):
         if self.category:
             try:
-                return get_article_class().objects.filter(category=self.category,
+                return get_article_class().objects.filter(
+                    sites__id=settings.SITE_ID, category=self.category,
+                    publication=BaseArticle.PUBLISHED,
                     publication_date__lt=self.publication_date).order_by('-publication_date')[0]
             except IndexError:
                 pass
 
-    def logo_thumbnail(self, temp=False, logo_size=None):
+    def logo_thumbnail(self, temp=False, logo_size=None, logo_crop=None):
         logo = self.temp_logo if (temp and self.temp_logo) else self.logo
         size = logo_size or get_article_logo_size(self)
         logo_file = None
@@ -420,9 +437,11 @@ class BaseArticle(BaseNavigable):
                 pass
         if not logo_file:
             logo_file = self._get_default_logo()
+        crop = logo_crop or get_article_logo_crop(self)
         try:
-            return sorl_thumbnail.backend.get_thumbnail(logo_file, size, crop='center')
+            return sorl_thumbnail.backend.get_thumbnail(logo_file, size, crop=crop)
         except Exception, msg:
+            print "#### ERR", msg
             return logo_file
 
     def _get_default_logo(self):
@@ -472,7 +491,8 @@ class BaseArticle(BaseNavigable):
                 locale_slug = getattr(self, loc_slug_var, '')
                 
                 if locale_title and not locale_slug:
-                    slug = self.get_unique_slug(loc_slug_var, locale_title)
+                    #slug = self.get_unique_slug(loc_slug_var, locale_title)
+                    slug = self.get_unique_slug('slug', locale_title)
                     setattr(self, loc_slug_var, slug)
         else:
             if not self.slug:
@@ -497,22 +517,41 @@ class BaseArticle(BaseNavigable):
         #no html in title
         title = dehtml(title)
         slug = slugify(title)
-        next, origin_slug = 2, slug
-        while True:
+        next_suffix, origin_slug = 2, slug
+        Article = get_article_class()
+        slug_exists = True
+        while slug_exists:
             #Check that this slug doesn't already exist
             #The slug must be unique for all sites
-            Article = get_article_class()
-            try:
-                attrs = {slug_field: slug}
-                if self.id:
-                    Article.objects.get(Q(**attrs) & ~Q(id=self.id))
-                else:
-                    Article.objects.get(**attrs)
+            if is_localized():
+                from modeltranslation.utils import build_localized_fieldname
+                slug_fields = []
+                for (lang_code, lang_name) in settings.LANGUAGES:
+                    loc_slug_var = build_localized_fieldname('slug', lang_code)
+                    slug_fields.append(loc_slug_var)
+            else:
+                slug_fields = ('slug',)
+            
+            slug_exists = False
+            for slug_field in slug_fields:
+                try:
+                    attrs = {slug_field: slug}
+                    if self.id:
+                        Article.objects.get(Q(**attrs) & ~Q(id=self.id))
+                    else:
+                        Article.objects.get(**attrs)
+                    #the slug exists in one language: we can not use it, try another one
+                    slug_exists = True
+                    break
+                except Article.DoesNotExist:
+                    pass #Ok this slug is not used: break the loop and return
+            
+            if slug_exists:
                 #oups the slug is already used: change it and try again
-                slug = u"{0}{1}".format(origin_slug, next)
-                next += 1
-            except Article.DoesNotExist:
-                break #Ok this slug is not used: break the loop and return
+                next_suffix_len = len(str(next_suffix))
+                safe_slug = origin_slug[:(100-next_suffix_len)]
+                slug = u"{0}{1}".format(safe_slug, next_suffix)
+                next_suffix += 1
         return slug
         
     def template_name(self):
@@ -892,11 +931,4 @@ class Fragment(models.Model):
         return super(Fragment, self).save(*args, **kwargs)
         
     def __unicode__(self):
-        return u"{0} {1} {2}".format(self.type, self.position, self.name)
-    
-    
-    
-
-
-
-    
\ No newline at end of file
+        return u"{0} {1} {2}".format(self.type, self.position, self.name)    
\ No newline at end of file
