@@ -46,9 +46,10 @@ class FragmentEditNode(DjalohaMultipleEditNode):
     def _get_object_lookup(self, obj):
         return {"id": obj.id}
 
-    def __init__(self, lookup):
+    def __init__(self, lookup, kwargs=None):
         super(FragmentEditNode, self).__init__(Fragment, lookup, 'content')
         self.fragment_filter = None
+        self.kwargs = kwargs or {}
     
     def _pre_object_render(self, obj):
         return u'<div class="coop-fragment {0}" rel="{1}">'.format(obj.css_class, obj.id)
@@ -56,9 +57,28 @@ class FragmentEditNode(DjalohaMultipleEditNode):
     def _post_object_render(self, obj):
         return u'</div>'
     
+    def _object_render(self, idx, obj, context):
+        value = getattr(obj, self._field_name)
+        template_name = self.kwargs.get('template_name', '')
+        if template_name:
+            template_name = self._resolve_arg(template_name, context)
+            t, _o = find_template(template_name)
+            object_content = t.render(template.Context({
+                'index': idx,
+                'fragment': self._render_value(context, self._get_object_lookup(obj), value),
+                'form': self._edit_mode #if_cms_edition --> active
+            }))
+        else:
+            object_content = self._pre_object_render(obj)
+            object_content += self._render_value(context, self._get_object_lookup(obj), value)
+            object_content += self._post_object_render(obj)
+        return object_content
+    
     def render(self, context):
+        self._edit_mode = False
         if context.get('form', None) or context.get('formset', None):
             context.dicts[0]['djaloha_edit'] = True
+            self._edit_mode = True
         #context.dicts[0]['can_edit_template'] = True
         html = super(FragmentEditNode, self).render(context)
         filter_id = self.fragment_filter.id if self.fragment_filter else ""
@@ -71,8 +91,15 @@ def coop_fragments(parser, token):
     args = token.split_contents()
     lookup = {'name': args[1]}
     if len(args) > 2:
-        lookup["extra_id"] = args[2]
-    return FragmentEditNode(lookup)
+        args2 = args[2]
+        if args2.find("=")<0:
+            lookup["extra_id"] = args2
+    kwargs = {}
+    for arg in args[2:]:
+        if arg.find("=")>0:
+            k, v = arg.split('=')
+            kwargs[k] = v
+    return FragmentEditNode(lookup, kwargs)
 
 ################################################################################
 class ArticleSummaryEditNode(DjalohaEditNode):
@@ -150,7 +177,7 @@ class IfCmsEditionNode(template.Node):
             yield node
 
     def _check_condition(self, context):
-        return context.get('form', None) or context.get('formset', None)
+        return context.get('form', None) or context.get('formset', None) 
 
     def render(self, context):
         if self._check_condition(context):
@@ -184,9 +211,10 @@ CMS_FORM_TEMPLATE = """
 
 class SafeWrapper:
 
-    def __init__(self, wrapped, logo_size=None):
+    def __init__(self, wrapped, logo_size=None, logo_crop=None):
         self._wrapped = wrapped
         self._logo_size = logo_size
+        self._logo_crop = logo_crop
 
     def __getattr__(self, field):
         value = getattr(self._wrapped, field)
@@ -194,7 +222,7 @@ class SafeWrapper:
         if hasattr(value, 'pk'):
             return value
         elif field=='logo':
-            src = getattr(self._wrapped, 'logo_thumbnail')(False, self._logo_size)
+            src = getattr(self._wrapped, 'logo_thumbnail')(False, self._logo_size, self._logo_crop)
             if src:
                 try:
                     t, _o = find_template("coop_cms/widgets/_img_logo.html")
@@ -211,11 +239,11 @@ class SafeWrapper:
 
 class FormWrapper:
 
-    def __init__(self, form, obj, logo_size=None):
+    def __init__(self, form, obj, logo_size=None, logo_crop=None):
         self._form = form
         self._obj = obj
         if logo_size:
-            self._form.set_logo_size(logo_size)
+            self._form.set_logo_size(logo_size, logo_crop)
 
     def __getitem__(self, field, logo_size=None):
         if field in self._form.fields.keys():
@@ -228,10 +256,13 @@ class FormWrapper:
 
 class CmsEditNode(template.Node):
 
-    def __init__(self, nodelist_content, var_name, logo_size=None):
+    def __init__(self, nodelist_content, var_name, logo_size=None, logo_crop=None):
         self.var_name = var_name
         self.nodelist_content = nodelist_content
-        self._logo_size = logo_size
+        self._logo_size = logo_size.strip("'").strip('"') if logo_size else None
+        self._logo_crop = logo_crop.strip("'").strip('"') if logo_crop else None
+        self._render_logo_size = self._logo_size and (self._logo_size!=logo_size)
+        self._render_logo_crop = self._logo_crop and (self._logo_crop!=logo_crop)
 
     def __iter__(self):
         for node in self.nodelist_content:
@@ -243,6 +274,12 @@ class CmsEditNode(template.Node):
         form = context.get('form', None)
         obj = context.get(self.var_name, None) if self.var_name else None
         
+        if self._render_logo_size:
+            self._logo_size = context.get(self._logo_size, None)
+            
+        if self._render_logo_crop:
+            self._logo_crop = context.get(self._logo_crop, None)
+        
         formset = context.get('formset', None)
         objects = context.get('objects', None)
 
@@ -269,17 +306,24 @@ class CmsEditNode(template.Node):
         if form or formset:
             t = template.Template(CMS_FORM_TEMPLATE)
             if form:
-                safe_context[self.var_name] = FormWrapper(form, obj, logo_size=self._logo_size)
+                safe_context[self.var_name] = FormWrapper(
+                    form, obj, logo_size=self._logo_size, logo_crop=self._logo_crop)
             else:
-                safe_context['objects'] = [FormWrapper(f, o, logo_size=self._logo_size) for (f, o) in zip(formset, objects)]
+                safe_context['objects'] = [
+                    FormWrapper(f, o, logo_size=self._logo_size, logo_crop=self._logo_crop)
+                    for (f, o) in zip(formset, objects)
+                ]
             outer_context.update(csrf(request))
             #outer_context['inner'] = self.nodelist_content.render(template.Context(inner_context))
         else:
             t = template.Template("{{inner|safe}}")
             if obj:
-                safe_context[self.var_name] = SafeWrapper(obj, logo_size=self._logo_size)
+                safe_context[self.var_name] = SafeWrapper(
+                    obj, logo_size=self._logo_size, logo_crop=self._logo_crop)
             else:
-                safe_context['objects'] = [SafeWrapper(o, logo_size=self._logo_size) for o in objects]
+                safe_context['objects'] = [
+                    SafeWrapper(o, logo_size=self._logo_size, logo_crop=self._logo_crop) for o in objects
+                ]
                 
         managed_node_types = [
             template.TextNode, template.defaulttags.IfNode, template.defaulttags.ForNode,
